---
title: <span class="badge builder"></span> VizTooltipOptions
---
# <span class="badge builder"></span> VizTooltipOptions

## Constructor

```python
VizTooltipOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.VizTooltipOptions
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.TooltipDisplayMode) -> typing.Self
```

### <span class="badge object-method"></span> sort

```python
def sort(sort: common.SortOrder) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [VizTooltipOptions](./object-VizTooltipOptions.md)
